@@ -40,6 +40,8 @@ $doc =~ s/<</\\dlt{}/g;
 $doc =~ s/>>/\\dgt{}/g;
 $doc =~ s/\\textasciitilde{}/\\\~{}/g;
 $doc =~ s/\\textasciicircum{}/\\\^{}/g;
+$doc =~ s/\\providecommand{\\tabularnewline}{\\\\}//;
+$doc =~ s/\\tabularnewline/\\\\/g;
 
 $doc =~ s/\(\(FDL\)\)/$fdl/g;
 $doc =~ s/\(\(LGPL\)\)/$lgpl/g;
